<?php

namespace SM\Service;

use SM\Factory\Sm00005000TabParametrizacoesEmailFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00005000TabParametrizacoesEmailService
{
    protected $connection;
    protected $parametrizacaoEmailFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00005000TabParametrizacoesEmailFactory $parametrizacaoEmailFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->parametrizacaoEmailFactory   = $parametrizacaoEmailFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getParametrosEmailFilial()
    {
        return $this->parametrizacaoEmailFactory->getParametrosEmailFilial();
    }

    public function saveParameterEmail($parametros)
    {
        $paramsValida = array(
            "NRPARAMEMAILFILIAL" => $parametros['NRPARAMEMAILFILIAL'],
            "CDFILIAL"           => $parametros['CDFILIAL'],
        );

        $valor = $this->parametrizacaoEmailFactory->validaRegistrosDuplicados($paramsValida);

        if ($valor[0]["QTD"] > 0) {
            throw new \Exception("EXISTE");
        }

        $this->connection->beginTransaction();
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        try {
            if ($parametros['NRPARAMEMAILFILIAL'] == null) {
                $nrparamemailfilial = $this->newCode->getCodeByTableName("FCT_PARAMEMAILFILIAL", $nrorg, 1, 10, true);
                $dataParams = array (
                    "NRPARAMEMAILFILIAL"    => $nrparamemailfilial,
                    "CDFILIAL"              => $parametros["CDFILIAL"],
                    "DSREMETENTEEMAIL"      => $parametros["DSREMETENTEEMAIL"],
                    "DSASSUNTOEMAIL"        => $parametros["DSASSUNTOEMAIL"],
                    "DSCORPOEMAIL"          => $parametros["DSCORPOEMAIL"],
                    "NRORG"                 => $nrorg,
                    "CDOPERINCLUSAO"        => $cdoperador,
                    "IDATIVO"               => "S",
                );
                $this->parametrizacaoEmailFactory->insertParameterEmail($dataParams);
            } else {
                $dataParams = array (
                    "NRPARAMEMAILFILIAL"    => $parametros["NRPARAMEMAILFILIAL"],
                    "CDFILIAL"              => $parametros["CDFILIAL"],
                    "DSREMETENTEEMAIL"      => $parametros["DSREMETENTEEMAIL"],
                    "DSASSUNTOEMAIL"        => $parametros["DSASSUNTOEMAIL"],
                    "DSCORPOEMAIL"          => $parametros["DSCORPOEMAIL"],
                    "NRORG"                 => $nrorg,
                    "CDOPERULTATU"          => $cdoperador,
                    "IDATIVO"               => "S",
                );
                $this->parametrizacaoEmailFactory->updateParameterEmail($dataParams);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteParametrosEmail($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $parametroEmail) {
                $dataParam = array( "NRPARAMEMAILFILIAL" => $parametroEmail["NRPARAMEMAILFILIAL"],);
                $this->parametrizacaoEmailFactory->deleteParametrosEmail($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
