import { Utilities } from '@/util/Utilities';
import { DialogService, LoadingService } from '@zeedhi/common';
import { Http, Loader, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class Sm00011000TabDadosAgrupamentoController {
    public tabApuracaoFaturamento = Loader.getInstance('Sm00011000TabApuracaoFaturamentoController');

    get tabInvisivel() {
        return this.tabApuracaoFaturamento.currentRow.IDPARCAGRUP !== 'S';
    }

    public showConfirmDialogMessageAgrupamento() {
        DialogService.show({
            name: 'warning_dialog',
            type: 'warning',
            title: 'Confirmação',
            text: 'Deseja realmente desagrupar os contratos selecionados?',
            buttons: [
                {
                    name: 'button-no',
                    component: 'ZdButton',
                    label: 'Não',
                    events: {
                        click: () => DialogService.hide(),
                    },
                    outline: true,
                },
                {
                    name: 'button-yes',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.desagruparContratoParcela();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public desagruparContratoParcela() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-agrupamentos');
        const selectedrows = grid.selectedRows;
        if (this.tabApuracaoFaturamento.currentRow.IDSITUACAO !== '1') {
            Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Não é possível desagrupar contratos de uma parcela com a situação diferente de Pendente');
        } else {
            const nrseqcontrato: any = [];

            selectedrows.forEach((parcela: any) => {
                nrseqcontrato.push(parcela.NRSEQCONTRATO);
            });

            const params = {
                NRFATURACONT: this.tabApuracaoFaturamento.currentRow.NRFATURACONT,
                NRSEQCONTRATO: nrseqcontrato,
                IDACAO: 'DESAGRUPA',
            };

            LoadingService.show();
            const gridApuracao = Metadata.getInstance<TekGrid>('basic-tek-grid-apuracao-faturamento');
            Http.post('/desagruparParcelasFaturamento', params)
                .then(() => {
                    Utilities.showSuccessMessage();
                    gridApuracao.datasource.get();
                    this.tabApuracaoFaturamento.voltarTekGridApuracao();
                    grid.selectedRows = [];
                }).catch((error) => {
                    if (error.response.data.error === 'ERRO') {
                        Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Falha ao efetuar o desmembramento de contratos');
                    } else {
                        Utilities.showErrorMessage(error);
                    }
                }).finally(() => {
                    LoadingService.hide();
                });
        }
    }
}
